to_saving — skchange

Skip to main content
`Ctrl`+`K`

# to_saving

to_saving(scorer: BaseCost | BaseSaving) → BaseSaving

  Convert compatible scorers to a saving.

  Parameters:
    scorerBaseCost or BaseSaving

      The scorer to convert to a saving. If a cost, it must be a cost with a fixed parameter. If a saving is provided, it is returned as is.

  Returns:
    savingBaseSaving

      The saving based on the cost function.